;------------------------------------------------------------------------------
; Copyright (c) Micromega Corporation 2004-2006. All rights reserved.
;
; @file		umfpu.inc
; @target	PICMicro
;
; This include file defines the uM-FPU opcodes.
;
; @author Cam Thompson, Micromega Corporation
; @version	V1.1 - May 19, 2006
; @changes
;	V1.1 - May 19, 2006
;	- changed WRITEA/WRITEB to FWRITEA/FWRITEB
;	V1.0 - November 12, 2004
;	- original release
;------------------------------------------------------------------------------

;-------------------- uM-FPU opcodes ------------------------------------------

#define	SELECTA		0x00		; select A register
#define SELECTB		0x10		; select B register
#define FWRITEA		0x20		; select A and write float to register
#define FWRITEB		0x30		; select B and write float to register
#define FREAD		0x40		; read float from register
#define FSET		0x50		; A = REG (float)
#define LSET		0x50		; A = REG (long)

#define FADD		0x60		; A = A + REG (float)
#define FSUB		0x70		; A = A - REG (float)
#define FMUL		0x80		; A = A * REG (float)
#define FDIV		0x90		; A = A / REG (float)

#define LADD		0xA0		; A = A + REG (long)
#define LSUB		0xB0		; A = A - REG (long)
#define LMUL		0xC0		; A = A * REG (long)
#define LDIV		0xD0		; A = A / REG (long)

#define SQRT		0xE0		; A = sqrt(A)
#define LOG			0xE1		; A = ln(A)
#define LOG10		0xE2		; A = log(A)
#define EXP			0xE3		; A = e ** A
#define EXP10		0xE4		; A = 10 ** A
#define SIN			0xE5		; A = sin(A) radians
#define COS			0xE6		; A = cos(A) radians
#define TAN			0xE7		; A = tan(A) radians
#define FLOOR		0xE8		; A = nearest integer <= A
#define CEIL		0xE9		; A = nearest integer >= A
#define ROUND		0xEA		; A = nearest integer to A
#define NEGATE		0xEB		; A = -A
#define FABS		0xEC		; A = |A|
#define INVERSE		0xED		; A = 1 / A
#define DEGREES		0xEE		; A = A / (PI / 180) radians to degrees
#define RADIANS		0xEF		; A = A * (PI / 180) degreees to radians
#define FSYNC		0xF0		; synchronization
#define FLOAT		0xF1		; copy A to register 0 and float
#define FIX			0xF2		; copy A to register 0 and fix
#define FCOMPARE	0xF3		; compare A and B
#define LOADBYTE	0xF4		; write signed byte to register 0, convert to float
#define LOADUBYTE	0xF5		; write unsigned byte to register 0, convert to float
#define LOADWORD	0xF6		; write signed word to register 0, convert to float
#define LOADUWORD	0xF7		; write unsigned word to register 0, convert to float
#define READSTR		0xF8		; read zero terminated string
#define ATOF		0xF9		; convert ASCII to float, store in A
#define FTOA		0xFA		; convert float to ASCII
#define ATOL		0xFB		; convert ASCII to long, store in A
#define LTOA		0xFC		; convert long to ASCII
#define FSTATUS		0xFD		; get the status of A register
#define XOP			0xFE		; extended opcode
#define FNOP		0xFF		; nop

#define FUNCTION	0x00		; (XOP) user functions 0-15
#define READBYTE    0x90		; (XOP) read low 8 bits of A (long)
#define READWORD    0x91		; (XOP) read low 16 bits of A (long)
#define READLONG    0x92		; (XOP) read 32-bit long value from A
#define READFLOAT   0x93		; (XOP) read floating point value from A
#define LINCA       0x94		; (XOP) A = A + 1 (long)
#define LINCB       0x95		; (XOP) A = A + 1 (long)
#define LDECA       0x96		; (XOP) A = A - 1 (long)
#define LDECB       0x97		; (XOP) A = A - 1 (long)
#define LAND        0x98		; (XOP) A = A AND B (long)
#define LOR         0x99		; (XOP) A = A OR B (long)
#define LXOR        0x9A		; (XOP) A = A XOR B (long)
#define LNOT        0x9B		; (XOP) A = NOT A (long)
#define LTST        0x9C		; (XOP) status of A AND B (long)
#define LSHIFT      0x9D		; (XOP) shift A by B bits (long)
#define LWRITEA		0xA0		; (XOP) select A and write long to register
#define LWRITEB		0xB0		; (XOP) select B and write long to register
#define LREAD		0xC0		; (XOP) read long from register
#define LUDIV		0xD0		; (XOP) A = A / REG (unsigned long)
#define POWER		0xE0		; (XOP) A = A ** B
#define ROOT		0xE1		; (XOP) A = the Bth root of A
#define FMIN		0xE2		; (XOP) A = minimum of A and B
#define FMAX 		0xE3		; (XOP) A = maximum of A and B
#define FRACTION	0xE4		; (XOP) load register 0 with the fractional part of A
#define ASIN		0xE5		; (XOP) A = asin(A) radians
#define ACOS		0xE6		; (XOP) A = acos(A) radians
#define ATAN		0xE7		; (XOP) A = atan(A) radians
#define ATAN2		0xE8		; (XOP) A = atan(A/B)
#define LCOMPARE	0xE9		; (XOP) long compare A and B
#define LUCOMPARE	0xEA		; (XOP) unsigned long compare A and B
#define LSTATUS		0xEB		; (XOP) long status
#define LNEGATE		0xEC		; (XOP) A = -A (long)
#define LABS		0xED		; (XOP) A = |A| (long)
#define LEFT		0xEE		; (XOP) right parenthesis
#define RIGHT		0xEF		; (XOP) left parenthesis
#define LOADZERO	0xF0		; (XOP) load register 0 with zero
#define LOADONE		0xF1		; (XOP) load register 0 with 1.0
#define LOADE		0xF2		; (XOP) load register 0 with e
#define LOADPI		0xF3		; (XOP) load register 0 with pi
#define LONGBYTE	0xF4		; (XOP) write signed byte to register 0, convert to long
#define LONGUBYTE	0xF5		; (XOP) write unsigned byte to register 0, convert to long
#define LONGWORD	0xF6		; (XOP) write signed word to register 0, convert to long
#define LONGUWORD	0xF7		; (XOP) write unsigned word to register 0, convert to long
#define IEEEMODE	0xF8		; (XOP) set IEEE mode (default)
#define PICMODE		0xF9		; (XOP) set PIC mode
#define CHECKSUM	0xFA		; (XOP) calculate code checksum
#define BREAK		0xFB		; (XOP) debug breakpoint
#define TRACEOFF	0xFC		; (XOP) turn debug trace off
#define TRACEON		0xFD		; (XOP) turn debug trace on
#define TRACESTR	0xFE		; (XOP) send debug string to trace buffer
#define VERSION     0xFF		; (XOP) get version string

#define SYNC_CHAR	0x5C		; sync character

;-------------------- support routines ----------------------------------------

	extern		fpu_reset
	extern		fpu_wait
	extern		fpu_sendByte
	extern		fpu_readByte
	extern		fpu_readDelay
